==> jc-1.4.0.tar.gz: gnu/javax/rmi/CORBA/GetDelegateInstanceException.h <==
// public class gnu.javax.rmi.CORBA.GetDelegateInstanceException

// class file dependencies
// @dep_class 872eb8dce7415646 gnu_javax_rmi_CORBA_GetDelegateInstanceException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_gnu_javax_rmi_CORBA_GetDelegateInstanceException_H_
#define _JC_gnu_javax_rmi_CORBA_GetDelegateInstanceException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_refs	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_refs;
typedef struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_nonrefs	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_nonrefs;
typedef struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$refs	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$refs;
typedef struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$nonrefs	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$nonrefs;
typedef struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$object	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$object;

typedef const struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vmethods	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vmethods;
typedef const struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtable	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtable;
typedef const struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtype	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtype;

// Constructors
extern void _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods structure
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vmethods {
};

// Vtable
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vmethods	gnu_javax_rmi_CORBA_GetDelegateInstanceException;
};

// Vtype
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtype {
	_jc_type			type;
	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_refs {
	struct _jc_java_lang_Throwable$object	*next;
};

// Reference instance fields (object)
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$refs {
    _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_refs	gnu_javax_rmi_CORBA_GetDelegateInstanceException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_nonrefs	gnu_javax_rmi_CORBA_GetDelegateInstanceException;
};

// Object instance structure
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$object {
	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtype	*vtype;
	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtype _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_javax_rmi_CORBA_GetDelegateInstanceException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$class_object;

#endif	/* _JC_gnu_javax_rmi_CORBA_GetDelegateInstanceException_H_ */

==> jc-1.4.6.tar.gz: gnu/javax/rmi/CORBA/GetDelegateInstanceException.h <==
// public class gnu.javax.rmi.CORBA.GetDelegateInstanceException

// class file dependencies
// @dep_class 872eb8dce7415646 gnu_javax_rmi_CORBA_GetDelegateInstanceException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_gnu_javax_rmi_CORBA_GetDelegateInstanceException_H_
#define _JC_gnu_javax_rmi_CORBA_GetDelegateInstanceException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_refs	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_refs;
typedef struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_nonrefs	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_nonrefs;
typedef struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$refs	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$refs;
typedef struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$nonrefs	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$nonrefs;
typedef struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$object	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$object;

typedef const struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vmethods	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vmethods;
typedef const struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtable	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtable;
typedef const struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtype	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtype;

// Constructors
extern void _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vmethods {
};

// Vtable
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vmethods	gnu_javax_rmi_CORBA_GetDelegateInstanceException;
};

// Vtype
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtype {
	_jc_type			type;
	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_refs {
	struct _jc_java_lang_Throwable$object	*next;
};

// Reference instance fields (object)
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$refs {
    _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_refs	gnu_javax_rmi_CORBA_GetDelegateInstanceException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$sub_nonrefs	gnu_javax_rmi_CORBA_GetDelegateInstanceException;
};

// Object instance structure
struct _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$object {
	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtype	*vtype;
	_jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$vtype _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_javax_rmi_CORBA_GetDelegateInstanceException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_javax_rmi_CORBA_GetDelegateInstanceException$class_object;

#endif	/* _JC_gnu_javax_rmi_CORBA_GetDelegateInstanceException_H_ */
